# angelovich.core

---
### Very basic components I use often

* DataStorage: ECS-like strictured storage, but not about performance.
* Dispatcher: async event dispatcher

#### TODO: improve description

#### TODO: add examples
